aboutsummaryrefslogtreecommitdiffstats
path: root/ports/darwin/guts/setxattr.c
diff options
context:
space:
mode:
Diffstat (limited to 'ports/darwin/guts/setxattr.c')
-rw-r--r--ports/darwin/guts/setxattr.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ports/darwin/guts/setxattr.c b/ports/darwin/guts/setxattr.c
index 9458a69..3c8fd3d 100644
--- a/ports/darwin/guts/setxattr.c
+++ b/ports/darwin/guts/setxattr.c
@@ -2,11 +2,11 @@
* Copyright (c) 2011 Wind River Systems; see
* guts/COPYRIGHT for information.
*
* int setxattr(const char *pathname, const char *name, const void *value, size_t size, int flags)
* int rc = -1;
*/
- rc = real_setxattr(pathname, name, value, size, flags);
+ rc = real_setxattr(pathname, name, value, size, position, options);
/* return rc;
* }
@@ -2,11 +2,11 @@
* guts/COPYRIGHT for information.
*
- * int setxattr(const char *pathname, const char *name, const void *value, size_t size, int flags)
+ * int setxattr(const char *pathname, const char *name, const void *value, size_t size, u_int32_t position, int options)
* int rc = -1;
*/